@@ -16,9 +16,9 @@ import glob
 import types
 from optparse import OptionParser
 
-from echonest.audio import *
-from echonest.audio import AudioQuantumList as aql
-from echonest.audio import AudioQuantum as aq
+from echonest.remix.audio import *
+from echonest.remix.audio import AudioQuantumList as aql
+from echonest.remix.audio import AudioQuantum as aq
 
 USAGE = '''
 %prog [options] [filename]
